<?php
/**
 * Wolf Decibel Version 3 Updater Old Home Header
 *
 * @author WolfThemes
 * @category Core
 * @package WolfDecibelVersion3Updater/Core
 * @version 1.0.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Check if we should display the old home header
 */
function wdv3u_display_home_header() {
	return ( wdv3u_get_home_id() &&  is_front_page() && ! is_paged() && 'none' !== wolf_get_theme_option( 'home_header_type' ) );
}

/**
 * Hide hero on home page
 */
function wdv3u_hide_default_hero( $bool ) {

	if ( wdv3u_display_home_header() ) {
		$bool = false;
	}

	return $bool;
}
add_filter( 'decibel_show_hero', 'wdv3u_hide_default_hero' );
add_filter( 'decibel_show_hero', 'wdv3u_hide_default_hero' );

/**
 * Set default her font tone
 */
function wdv3u_set_default_hero_font_tone( $tone ) {
	if ( wdv3u_display_home_header() ) {
		$tone = 'light';
	}

	return $tone;
}
add_filter( 'decibel_default_hero_font_tone', 'wdv3u_set_default_hero_font_tone' );
add_filter( 'decibel_default_hero_font_tone', 'wdv3u_set_default_hero_font_tone' );

/**
 * Output Old Header
 */
function wdv3u_old_header() {

	if ( is_404() || 'none' === wolf_get_theme_option( 'home_header_type' ) ) {
		return;
	}

	if ( wdv3u_display_home_header() ) {

		/**
		 * Home Header
		 */
		$header_type = wolf_get_theme_option( 'home_header_type' );
		$hero = stripslashes( wolf_get_theme_option( 'home_header_content' ) );
		$font_color = wolf_get_theme_option( 'header_bg_font_color' );
		$full_height = wolf_get_theme_option( 'full_screen_header' );
		$min_height = ( wolf_get_theme_option( 'home_header_height' ) ) ? wolf_get_theme_option( 'home_header_height' ) : 70;
		$overlay_color = wolf_get_theme_option( 'header_overlay_color' );
		$overlay_opacity = wolf_get_theme_option( 'header_overlay_opacity' );

		// Featured Post Slider
		if ( 'featured-slider' == $header_type ) {
			if ( 0 < wolf_get_slide_loop()->post_count ) {
				if ( function_exists( 'wdv3u_slider_home' ) ) {
					wdv3u_featured_slider_home();
				}
			}
		
		} elseif ( 'standard' == $header_type || 'video' == $header_type ) {

			if ( 'standard' === $header_type ) {
				$header_type = 'image';
			}

			if ( ! wolf_is_slider_in_home_header() ) {
				
				$bg_img = wolf_get_theme_option( 'header_bg_img' );
				$bg_color = wolf_get_theme_option( 'header_bg_color' );
				$bg_repeat = wolf_get_theme_option( 'header_bg_repeat' );
				$bg_position = wolf_get_theme_option( 'header_bg_position' );
				$bg_size = wolf_get_theme_option( 'header_bg_size' );
				$bg_effect = wolf_get_theme_option( 'hero_effect' );
				$scroll_down = wolf_get_theme_option( 'scroll_down_arrow' );

				if ( ! wolf_is_slider_in_home_header() ) {

					$row_output = '[vc_row';

					$row_output .= ' background_type="' . $header_type . '" font_color="' . $font_color . '"';

					if ( $bg_effect ) {
						$row_output .= ' background_effect="' . esc_attr( $bg_effect ) . '"';
					}

					if ( 'image' === $header_type ) {

						$row_output .= ' background_repeat="' . esc_attr( $bg_repeat ) . '"';
						$row_output .= ' background_position="' . esc_attr( $bg_position ) . '"';
						$row_output .= ' background_size="' . esc_attr( $bg_size ) . '"';
						$row_output .= ' background_img="' . absint( $bg_img ) . '"';

						if ( $bg_color ) {
							$row_output .= ' background_color="custom" background_custom_color="' . $bg_color . '"';
						}


					} elseif ( 'video' === $header_type ) {

						$video_url = '';
						$video_type = wolf_get_theme_option( 'video_header_bg_type' );
						$video_img = wolf_get_attachment_id_from_url( wolf_get_theme_option( 'video_header_bg_img' ) );

						if ( 'youtube' === $video_type ) {
							
							$video_url = wolf_get_theme_option( 'video_header_bg_youtube_url' );
						
						} elseif ( 'selfhosted' === $video_type ) {

							$video_url = wolf_get_theme_option( 'video_header_bg_mp4' );

						}

						if ( $video_img ) {
							$row_output .= ' video_bg_img="' . absibnt( $video_img ) . '"';
						}

						if ( $video_url ) {
							$row_output .= ' video_bg_url="' . esc_attr( $video_url ) . '"';
						}
					}

					if ( $overlay_color ) {
						$row_output .= ' add_overlay="yes"';
						$row_output .= ' overlay_color="custom" overlay_custom_color="' . $overlay_color . '"';
					}

					if ( $full_height ) {
						$row_output .= ' full_height="true"';
					}

					if ( $min_height ) {
						$row_output .= ' min_height="' . absint( $min_height ) . 'vh"';
					}

					if ( $scroll_down ) {
						$row_output .= ' arrow_down="true"';
					}

					$row_output .= ' content_placement="middle" columns_placement="middle"';

					$row_output .= '][vc_column width="1/1"][vc_column_text]';

					$row_output .= wpb_js_remove_wpautop( $hero );

					$row_output .= '[/vc_column_text][/vc_column][/vc_row]';

					//debug( $row_output );

					echo do_shortcode( $row_output );
				
				} elseif ( $hero && wolf_is_slider_in_home_header() ) {
					?>
					<div class="wolf-the-slider-container"><?php echo wpb_js_remove_wpautop( $hero ); ?></div>
					<?php
				}
				echo '</div>';
			}

		} elseif ( 'wolf-slider' === $header_type ) {

			if ( wolf_get_theme_option( 'header_wolf_slider' ) ) {
				if ( function_exists( 'wolf_slider' ) ) {
					wolf_slider( esc_attr( wolf_get_theme_option( 'header_wolf_slider' ) ) );
				}
			}

		} elseif ( 'revslider' ==  $header_type ) {

			if ( wolf_get_theme_option( 'header_revslider' ) ) : ?>
				<div class="wolf-revslider-container">
					<?php
						if ( function_exists( 'putRevSlider' ) )
							putRevSlider( esc_attr( wolf_get_theme_option( 'header_revslider' ) ) ); 
					?>
				</div>
			<?php endif;
		}

	} // end if home
}
add_action( 'decibel_hero', 'wdv3u_old_header' );
add_action( 'decibel_hero', 'wdv3u_old_header' );

/**
 * Featured post slider
 */
function wdv3u_featured_slider_home() {
	
	$loop = wolf_get_slide_loop();

	$slider_speed = wolf_get_theme_option( 'slider_speed' ) ? absint( wolf_get_theme_option( 'slider_speed' ) ) : 5000;
	$pause_on_hover = wolf_get_theme_option( 'slider_speed' ) ?  'true' : 'false';
	$slideshow = wolf_get_theme_option( 'slider_autoplay' ) ?  'true' : 'false';

	if ( $loop->have_posts() ) {

		?>
			<script type="text/javascript">
			jQuery( document ).ready(function(){
				var defaultTransition = ( Modernizr.isTouch ) ? 'slide' : 'fade',
					homeSliderTransition = WolfThemeParams.sliderEffect;
				if ( 'auto' === WolfThemeParams.sliderEffect ) {
					homeSliderTransition = defaultTransition;
				}
				jQuery( '#featured-post-wolf-slider' ).wolfslider( {
					animation: 'fade',
					slideshow : <?php echo esc_attr( $slideshow ); ?>,
					pauseOnHover: <?php echo esc_attr( $pause_on_hover ); ?>,
					slideshowSpeed : <?php echo absint( $slider_speed ); ?>
				} );
			} );
		</script>
		<div class="wolf-slider-container content-light-font">
			<div id="featured-post-wolf-slider" class="wolf-slider flexslider">
				<ul class="slides">
				<?php while ( $loop->have_posts() ) : $loop->the_post(); 
				?>
					<?php $img_url = wolf_get_post_thumbnail_url( 'extra-large' ); ?>
					<li class="slide wolf-slide slide-<?php echo esc_attr( get_post_type() ); ?> wolf-slide-text-align-left caption-valign-middle" id="post-slide-<?php the_ID(); ?>">
						<span class="wolf-slide-bg parallax-inner" style="background:url('<?php echo esc_url( $img_url ); ?>') 50% 50% no-repeat; background-size:cover;"></span>
						<span class="header-overlay"></span>
						<?php
						$post_id = get_the_ID();
						$post_type = get_post_type();
						?>
						<span class="wolf-slide-caption-container">
							<span class="wolf-slide-caption">
								<span class="wrap">
									<span data-max-font-size="48" class="fittext wolf-slide-title"><?php the_title(); ?></span>
									<span class="wolf-slide-subtitle"><?php echo sanitize_text_field( wolf_sample( wolf_excerpt( false ), 140 ) ); ?></span>
									<span class="wolf-slide-button-container">
										<a href="<?php the_permalink(); ?>" class="wolf-button border-button medium square in-site"><?php echo sanitize_text_field( wolf_more_text() ); ?></a>
									</span>
									<?php edit_post_link( __( 'Edit', 'wolf-decibel-v3-updater' ), '<span class="edit-link">', '</span>' ); ?>
								</span><!-- .wrap -->
							</span><!-- .wolf-slide-caption -->
						</span><!-- .wolf-slide-caption-container -->
					</li>
				<?php endwhile; wp_reset_postdata(); ?>
				</ul>
			</div>
		</div>
		<?php

	}
}