<?php
/**
 * Wolf Decibel Version 3 Updater admin notices
 *
 * @author WolfThemes
 * @category Core
 * @package WolfDecibelVersion3Updater/Core
 * @version 1.0.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

function wdv3u_is_about_page() {
	return ( isset( $_GET['page'] ) && wdv3u_get_theme_slug() . '-about' === $_GET['page'] );
}

/**
 * Instructions
 */
function decibel_v3_update_instructions() {

	wp_enqueue_style( 'font-awesome', get_template_directory_uri() . '/assets/css/lib/fonts/fontawesome/font-awesome.min.css', array(), '4.6.3' );

	if ( ! wdv3u_is_about_page() ) {
		?>
		<style>
			#<?php echo wdv3u_get_theme_slug(); ?>-v3-instructions{
				font-size: 1.2em;
			}
		</style>
		<div id="<?php echo wdv3u_get_theme_slug(); ?>-v3-instructions">
		<?php
	}

	if ( wdv3u_is_about_page() ) :
	?>
	<h4><?php esc_html_e( 'Important: What you need to do if you update from version 2.0', 'wolf-decibel-v3-updater' ); ?></h4>
	<?php else: ?>
	<h2><?php esc_html_e( 'Important: What you need to do.', 'wolf-decibel-v3-updater' ); ?></h2>
	<?php endif; ?>
	<ol class="n-list">
		<li><?php printf(
			wp_kses_post( __( 'Install all the new recommended plugins using the <a href="%s" target="_blank">plugin installer</a>.', 'wolf-decibel-v3-updater' ) ),
			esc_url( admin_url( 'themes.php?page=tgmpa-install-plugins' ) )
		); ?>
		<a class="q-mark" title="<?php esc_attr_e( 'Help', 'wolf-decibel-v3-updater' ); ?>" href="https://wolfthemes.ticksy.com/article/11655/" target="_blank"><span class="dashicons dashicons-editor-help"></span></a>
		</li>
		<li><?php printf( wp_kses_post( __( 'Make sure that your server fullfils the minimum requirements in the <a href="%s" target="_blank">System Status</a> tab.', 'wolf-decibel-v3-updater' ) ),
			'https://wolfthemes.ticksy.com//article/11654/'
		); ?>
		<a class="q-mark" title="<?php esc_attr_e( 'Help', 'wolf-decibel-v3-updater' ); ?>" href="https://wolfthemes.ticksy.com/article/11651/" target="_blank"><span class="dashicons dashicons-editor-help"></span></a>
		</li>
		<li><?php printf(
			wp_kses_post( __( 'Update <a href="%s" target="_blank">WPBakery Page Builder</a> (formerly Visual Composer) and <a href="%s" target="_blank">Slider Revolution</a> plugins to their latest version.', 'wolf-decibel-v3-updater' ) ),
			'https://wlfthm.es/wpbpb',
			'https://wlfthm.es/revslider'
		); ?>
			<a class="q-mark" title="<?php esc_attr_e( 'Help', 'wolf-decibel-v3-updater' ); ?>" href="https://wolfthemes.ticksy.com/article/11671/" target="_blank"><span class="dashicons dashicons-editor-help"></span></a>
		</li>
		<li><?php printf(
			wp_kses_post( __( 'Activate the <a href="%s" target="_blank">Wolf WPBakery Page Builder Extension</a> plugin.', 'wolf-decibel-v3-updater' ) ),
			'https://wolfthemes.ticksy.com/article/14866'
		); ?>
			<a class="q-mark" title="<?php esc_attr_e( 'Help', 'wolf-decibel-v3-updater' ); ?>" href="https://wolfthemes.ticksy.com/article/13268/" target="_blank"><span class="dashicons dashicons-editor-help"></span></a>
		</li>
		<?php if ( wdv3u_is_about_page() ) : ?>		
		<li><?php printf(
			wp_kses_post( __( 'Run the <a href="%s">%s updater</a> to update your data for this new version of %s.', 'wolf-decibel-v3-updater' ) ),
			'https://wlfthm.es/decibel-v3',
			wdv3u_get_theme_name(),
			wdv3u_get_theme_name()

		); ?></li>
		<?php endif; ?>
		<li><?php printf(
			wp_kses_post( __( 'After running the updater, it is recommended to review your websites to check if slight edits are needed.', 'wolf-decibel-v3-updater' ) )
		); ?></li>
		<li><?php printf(  __( 'Some elements can\'t be updated automatically (marked with the %s icon). You can keep this plugin installed as long as you use these deprecated elements', 'wolf-decibel-v3-updater' ),
			'<i class="fa fa-undo"></i>'
		); ?></li>
		<li><?php printf(
			wp_kses_post( __( 'Optionally, you may need to run the <a href="%s" target="_blank">Force Regenerate Thumbnails</a> plugin to resize all your images after the update..', 'wolf-decibel-v3-updater' ) ),
			esc_url( admin_url( 'tools.php?page=force-regenerate-thumbnails' ) )
		); ?></li>
	</ol>
	<?php
	if ( ! wdv3u_is_about_page() ) {
		?>
	</div>
		<?php
	}
	
}

/**
 * Admn notifications
 */
function wdv3u_admin_notices() {
	global $pagenow;

	$post_type = '';

	$theme_slug = wdv3u_get_theme_slug();

	if ( isset( $_GET['post_type'] ) ) {
		$post_type = esc_attr( $_GET['post_type'] );

	} elseif ( isset( $_GET['post'] ) ) {
		$post_type = get_post_type( absint( $_GET['post'] ) );
	}

	$taxonomy = ( isset( $_GET['taxonomy'] ) ) ? $_GET['taxonomy'] : null;

	if (
		( 'slide' === $post_type && ( 'post.php' === $pagenow || 'post-new.php' === $pagenow  ) )
	|| ( isset( $_GET['post_type'] ) && 'slide' === $_GET['post_type']  )
	|| ( 'slide_category' === $taxonomy )
	) {
		$message = sprintf( __( 'The Home Slider is a deprecated feature. It is recommended to use the <strong>Advanced Slider</strong> page builder element instead and insert it in a <a href="%s" target="_blank">Content Block</a> or directly into your page.', 'wolf-decibel-v3-updater' ), 'https://wolfthemes.ticksy.com/article/12792' );
		$cookie_id = $theme_slug . '_wolf_slider_deprecated';

		wdv3u_admin_notice( $message, 'warning' );
	}

	if (
		( 'show' === $post_type && ( 'post.php' === $pagenow || 'post-new.php' === $pagenow  ) )
	|| ( isset( $_GET['post_type'] ) && 'show' === $_GET['post_type']  )
	) {
		$message = sprintf( __( 'The Tour Dates plugin is deprecated. It is recommended to use the <a href="%s" target="_blank">Wolf Events</a> plugin instead.', 'wolf-decibel-v3-updater' ),
			'https://plugins.wolfthemes.com/wolf-events/wolf-events.zip'
		);
		$cookie_id = $theme_slug . '_wolf_tour_dates_deprecated';

		wdv3u_admin_notice( $message, 'warning' );
	}

	$page_display_updater_message = array( wdv3u_get_theme_slug() . '-about' );
	
	if ( ( 'index.php' === $pagenow || ( isset( $_GET['page'] ) && in_array( $_GET['page'], $page_display_updater_message ) ) ) && ! defined( 'DOING_AJAX' ) && ! get_option( 'decibel_v3_update_status' ) ) {

		$cookie_id = $theme_slug . '_wolf_run_updater';

		$message = '<h3>';
		$message .= sprintf( __( '%s has been updated!', 'wolf-decibel-v3-updater' ), wdv3u_get_theme_name() );
		$message .= '</h3>';

		$message .= sprintf( __( '<h4>To keep things running smoothly, we have to update your content.</h4>', 'wolf-decibel-v3-updater' ) );

		$message .= sprintf( __( '<h3 style="font-size:18px;">Important: first, be sure to <a href="%s">activate the recommended plugins</a>.</h3>', 'wolf-decibel-v3-updater' ),
			admin_url( 'themes.php?page=tgmpa-install-plugins' ) );
		
		$message .= '<ol style="font-size:16px;margin-left: 20px;">';

		$message .= '<li>';
		$message .= sprintf( __( 'Be sure that your WordPress installation and all recommended plugins are up-to-date.', 'wolf-decibel-v3-updater' ) );
		$message .= '</li>';

		$instruction_link = ( class_exists( 'Wolf_Decibel_Version3_Updater' ) ) ? admin_url( 'tools.php?page=wolf-decibel-v3-updater' ) : admin_url( 'themes.php?page=decibel-about' );
		$instruction_page_title = ( class_exists( 'Wolf_Decibel_Version3_Updater' ) ) ? 'instruction' : '"About the Theme"';

		$message .= '<li>';
		$message .= sprintf( __( 'You will find more info in the <a href="%s">%s</a> page.', 'wolf-decibel-v3-updater' ),
			$instruction_link,
			$instruction_page_title
		);
		$message .= '</li>';

		$message .= '<li>';
		$message .= sprintf( __( 'We recommend <a href="%s" target="_blank">creating a backup of your site</a> before updating.', 'wolf-decibel-v3-updater' ), 'https://www.wpbeginner.com/plugins/7-best-wordpress-backup-plugins-compared-pros-and-cons/' );
		$message .= '</li>';

		$message .= '<li>';
		$message .= sprintf( __( 'The update process runs in the background and may take a little while, so please be patient.', 'wolf-decibel-v3-updater' ) );
		$message .= '</li>';
		$message .= '</ol>';

		$message .= sprintf(
			wp_kses_post( __( '<br><p><a href="%s" class="button button-primary button-hero">Run the Updater</a></p>', 'wolf-decibel-v3-updater' ) ),
			esc_url( admin_url( 'index.php?' . $theme_slug . '-process-update' ) )
		);

		// $message .= '<br><p>';
		// $message .= sprintf(
		// 	wp_kses_post( __( '<a href="%1$s">No thanks</a><br>', 'wolf-decibel-v3-updater' ) ),
		// 	esc_url( admin_url( 'index.php?' . $theme_slug . '-skip-update=yes' ) )
		// );
		// $message .= '</p>';

		wdv3u_admin_notice( $message, 'info' );
	}

	if ( ( 'index.php' === $pagenow || ( isset( $_GET['page'] ) && in_array( $_GET['page'], $page_display_updater_message ) ) ) && ! defined( 'DOING_AJAX' ) && 'launched' === get_option( 'decibel_v3_update_status' ) ) {

		$message = esc_html__( 'The update process is running in the background and it may take a while. You will be notified when it is done.', 'wolf-decibel-v3-updater' );

		wdv3u_admin_notice( $message, 'info' );

		update_option( 'decibel_v3_update_status', 'processing' );
	}

	$page_display_updater_message = array( 'decibel-about', 'wolf-decibel-v3-updater' );
	
	if ( ( 'index.php' === $pagenow || ( isset( $_GET['page'] ) && in_array( $_GET['page'], $page_display_updater_message ) ) ) && ! defined( 'DOING_AJAX' ) && 'completed' === get_option( 'decibel_v3_update_status' ) ) {

		$message = sprintf( __( '%s update complete. Thank you for updating to the latest version!', 'wolf-decibel-v3-updater' ), wdv3u_get_theme_name() );

		$message .= '<br>';

		$message .= sprintf( __( 'A lot of changes and improvements have been made in this new version of %s. It is recommended to review your websites to check if slight edits are needed.', 'wolf-decibel-v3-updater' ), wdv3u_get_theme_name() );

		wdv3u_admin_notice( $message, 'info' );

		update_option( 'decibel_v3_update_status', 'finished' );
	}
}
add_action( 'admin_init', 'wdv3u_admin_notices' );



/**
 * Custom admin notice
 *
 * @param string $message
 * @param string $type error|warning|info|success
 * @param string $cookie_id if set a cookie will be use to hide the notice permanently
 */
function wdv3u_admin_notice( $message = null, $type = null, $cookie_id = null, $dismiss_text = null ) {

	if ( ! $message ) {
		return;
	}

	$is_dismissible = ( 'error' == $message ) ? '' : 'is-dismissible';

	if ( $cookie_id ) {

		if ( ! $dismiss_text ) {
			$dismiss_text = esc_html__( 'Hide permanently', 'wolf-decibel-v3-updater' );
		}

		if ( $cookie_id ) {
			if ( ! isset( $_COOKIE[ $cookie_id ] ) ) {
				$href = esc_url( admin_url( 'themes.php?page=' . wdv3u_get_theme_slug() . '-about&amp;dismiss=' . $cookie_id ) );
				echo "<div class='notice notice-$type $is_dismissible'><p>$message</p><p><a href='$href' id='$cookie_id' class='button decibel-dismiss-admin-notice'>$dismiss_text</a></p></div>";
			}
		}
	} else {
		echo "<div class='notice notice-$type $is_dismissible'><p>$message</p></div>";
	}
	return false;
}
add_action( 'admin_notices', 'wdv3u_admin_notice' );