<?php
/**
 * Wolf Decibel Version 3 Updater core functions
 *
 * General core functions available on admin and frontend
 *
 * @author WolfThemes
 * @category Core
 * @package WolfDecibelVersion3Updater/Core
 * @version 1.0.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Get site name slug
 *
 * @return string
 */
function wdv3u_get_theme_slug() {
	return apply_filters( 'decibel_theme_slug', esc_attr( sanitize_title_with_dashes( get_template() ) ) );
}

/**
 * Get theme name
 *
 * @return string
 */
function wdv3u_get_theme_name() {
	$theme = wp_get_theme();
	return $theme->get( 'Name' );
}

/**
 * Get option
 *
 * @param string $value
 * @return string
 */
function wdv3u_get_option( $value = null, $default = null ) {

	global $options;

	$wolf_decibel_v3_updater_settings = get_option( 'wolf_decibel_v3_updater_settings' );

	if ( isset( $wolf_decibel_v3_updater_settings[ $value ] ) && '' != $wolf_decibel_v3_updater_settings[ $value ] ) {

		return $wolf_decibel_v3_updater_settings[ $value ];

	} elseif ( $default ) {

		return $default;
	}
}

/**
 * Get the URL of an attachment from its id
 *
 * @param int $id
 * @return string $url
 */
function wdv3u_get_url_from_attachment_id( $id, $size = 'thumbnail' ) {

	$src = wp_get_attachment_image_src( $id, $size );
	if ( isset( $src[0] ) ) {
		return esc_url( $src[0] );
	}
}

/**
 * Get shortcode attribute regex
 */
function wdv3u_get_shortcode_atts_regex() {
	$regex = '[a-zA-ZŽžšŠÀÁÂÃÄÅàáâãäåÒÓÔÕÖØòóôõöøÈÉÊËèéêëÇçČčÌÍÎÏìíîïÙÚÛÜùúûüÿÑñйА-я= {}0-9#@|\%_\.:;,+\/\/\?!\'%&€^¨°¤£$§~()`*"-]+';

	return $regex;
}

function wdv3u_get_home_id() {
	return get_option( 'page_on_front' );
}

/**
 * Check if Color is hex color
 */
function wdv3u_is_hex( $string ) {
	return ( 1 === preg_match( '|^#([A-Fa-f0-9]{3}){1,2}$|', $string ) );
}

if ( ! function_exists( 'debug' ) ) {
	/**
	 *  Debug function for developpment
	 *  Display less infos than a var_dump
	 *
	 * @param string $var
	 * @return string
	 */
	function debug( $var ) {
		if ( WP_DEBUG ) {
			echo '<br><pre style="border: 1px solid #ccc; padding:5px; width:98%">';
			print_r( $var );
			echo '</pre>';
		}
	}
}

if ( ! function_exists( 'd3_log' ) ) {
	
	function d3_log( $v ) {
		error_log( $v . PHP_EOL , 3, WOLF_BACKCOMPAT_DIR .  '/debug.log' );
	}
}

if ( ! function_exists( 'wolf_do_button' ) ) {
	/**
	 * Output a button with paramters from shortcode
	 *
	 * @param
	 * @return string $button
	 */
	function wolf_do_button(
		$text = '',
		$link = '#',
		$tagline = '',
		$color = '',
		$type = 'square',
		$size = 'medium',
		$custom_style = 'no',
		$button_bg_color = null,
		$button_font_color = null,
		$button_border_color = null,
		$button_bg_color_hover = null,
		$button_font_color_hover = null,
		$button_border_color_hover = null,
		$add_button_icon = false,
		$icon = null,
		$icon_position = 'after',
		$target = '',
		$scroll_to_anchor = '',
		$inline_style = '',
		$class = '',
		$id = ''
	) {

		// style
		$style = '';
		$data_bg_color = '';
		$data_font_color = '';
		$data_border_color = '';

		if ( 'yes' == $custom_style ) {
			if ( $button_bg_color )
				$style .= "background-color:$button_bg_color;";

			if ( $button_font_color )
				$style .= "color:$button_font_color;";

			if ( $button_border_color )
				$style .= "border-color:$button_border_color;";

			// hover style
			if ( $button_bg_color_hover )
				$data_bg_color = " data-hover-bg-color='$button_bg_color_hover'";

			if ( $button_font_color_hover )
				$data_font_color = " data-hover-font-color='$button_font_color_hover'";

			if ( $button_border_color_hover )
				$data_border_color = " data-hover-border-color='$button_border_color_hover'";
		}

		if ( $inline_style ) {
			$style .= $inline_style;
		}

		$style = ( $style ) ? " style='$style'" : '';

		// link
		//$href = esc_url( $link );
		$href = $link;

		// class
		$class = ( $class ) ? "$class " : ''; // add space
		$class .= 'wolf-button';
		$class .= ( 'yes' == $custom_style ) ? ' wolf-button-custom-style' : '';
		$class .= ' ' . $size;
		$class .= ' ' . $type;
		$class .= " icon_$icon_position";

		if ( $tagline ) {
			$class .= ' has-tagline';
		}

		if ( 'no' == $custom_style ) $class .= ' ' . $color;

		if ( $scroll_to_anchor )
			$class .= ' scroll';

		// icon
		$icon = ( 'yes' == $add_button_icon ) ? "<i class='fa $icon'></i> " : '';
		$tagline = ( $tagline ) ? "<span class='wolf-button-tagline'>$tagline</span>" : '';
		$button = '';
		$button .= '<a '; // beggin button
		$button .= $style;
		$button .= " class='$class'";
		$button .= " href='$href'";
		$button .= " target='$target'";
		$button .= $data_bg_color;
		$button .= $data_font_color;
		$button .= $data_border_color;
		$button .= '>';

		if ( 'before' == $icon_position ) $button .= $icon; // icon before

		$button .= $text; // text

		if ( 'after' == $icon_position ) $button .= $icon; // icon after

		$button .= $tagline; // tagline

		$button .= '</a>'; // end button

		return $button;
	}
}

if ( ! function_exists( 'wolf_sample' ) ) {
	/**
	 * Create a formatted sample of any text
	 *
	 * Remove HTML and shortcode, sanitize and shorten a string
	 *
	 * @param string $text
	 * @param int $num_words
	 * @param string $more
	 * @return string
	 */
	function wolf_sample( $text, $num_words = 55, $more = '...' ) {
		$text = wp_strip_all_tags( wp_trim_words( strip_shortcodes( $text ), $num_words, $more ) );
		$text = preg_replace( '/(http:|https:)?\/\/[a-zA-Z0-9\/.?&=-]+/', '', $text );
		return $text;
	}
}

if ( ! function_exists( 'wolf_clean_spaces' ) ) {
	/**
 * Remove all double spaces and line breaks
 *
 * This function is mainly used to clean up inline CSS
 *
 * @param string $css
 * @return string
 */
function wolf_clean_spaces( $string, $hard = false ) {

	if ( $hard ) {
			return str_replace( ' ', '', $string );
		} else {
			return preg_replace( '/\s+/', ' ', $string );
		}
	}
}

if ( ! function_exists( 'wolf_mailchimp' ) ) {
	/**
	 * Return a mailchimp Subscription form
	 *
	 * @param string $list
	 * @param string $size
	 * @param string $label
	 * @param string $submit
	 * @return string $output
	 */
	function wolf_mailchimp( $list, $size = 'normal', $label = '', $submit = 'Subscribe', $button_style = '', $alignment = 'center', $animation = '', $animation_delay = '', $inline_style = '', $class = '' ) {

		$class = ( $class ) ? "$class " : ''; // add space
		$class .= "wolf-mailchimp-form $size wolf-mailchimp-align-$alignment";
		$style = '';

		if ( $animation )
			$class .= " wow $animation";

		if ( $animation_delay && 'none' != $animation ) {
			$style .= 'animation-delay:' . absint( $animation_delay ) / 1000 . 's;-webkit-animation-delay:' . absint( $animation_delay ) / 1000 . 's;';
		}

		if ( $inline_style ) {
			$style .= $inline_style;
		}

		$style = ( $style ) ? " style='$style'" : '';

		$output = "<form class='$class'$style><input type='hidden' name='wolf-mailchimp-list' class='wolf-mailchimp-list' value='$list'>";
		if ( $label )
			$output .= "<h3 class='widget-title'>$label</h3>";
		$output .= '<div class="wolf-mailchimp-email-container"><input placeholder="' . __( 'your email', 'wolf-decibel-v3-updater' ) . '"  type="text" name="wolf-mailchimp-email" class="wolf-mailchimp-email"></div>';
		$output .= "<div class='wolf-mailchimp-submit-container'><input type='submit' name='wolf-mailchimp-submit' class='wolf-mailchimp-submit $button_style' value='$submit'></div>";
		$output .= '<span class="wolf-mailchimp-result">&nbsp;</span>';
		$output .= '</form>';

		if ( wolf_get_theme_option( 'mailchimp_api_key' ) && ! empty( $list ) ) {

			return $output;

		} elseif ( is_user_logged_in() ) {

			$output = '<p class="text-center">';

			if ( ! wolf_get_theme_option( 'mailchimp_api_key' ) )
				$output .= __( 'You must set your mailchimp API key in the theme options', 'wolf-decibel-v3-updater' ) . '<br>';

			if ( ! $list )
				$output .= __( 'You must set a list ID!', 'wolf-decibel-v3-updater' );

			$output .= '</p>';
			return $output;
		}
	}
}