<?php
/**
 * Wolf Decibel Version 3 Updater default options
 *
 * Set default options for Decibel v3
 *
 * @author WolfThemes
 * @category Core
 * @package WolfDecibelVersion3Updater/Core
 * @version 1.0.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Fire option functions
 */
function wdv3_fire_options() {
	wdv3_set_default_options();
	wdv3_update_options();
}
add_action( 'admin_init', 'wdv3_fire_options' );

/**
 * Set default options
 */
function wdv3_set_default_options() {
	
	if ( get_option( 'decibel_v3_default_options_init' ) ) {
		return;
	}

	update_option( 'wpb_js_gutenberg_disable', true );
	update_option( 'image_default_link_type', 'file' );
	update_option( 'thumbnail_size_w', 260 );
	update_option( 'thumbnail_size_h', 260 );
	update_option( 'thumbnail_crop', 1 );
	update_option( 'medium_size_w', 600 );
	update_option( 'medium_size_h', 600 );
	update_option( 'large_size_w', 1200 );
	update_option( 'large_size_h', 1024 );
	update_option( 'thread_comments_depth', 2 );

	update_option( 'decibel_dismiss_demo_data_import', true );

	delete_user_meta( get_current_user_id(), 'tgmpa_dismissed_notice_tgmpa' );

	update_option( 'decibel_v3_default_options_init', true );
}

/**
 * Check for old options and move them to the customizer
 */
function wdv3_update_options() {

	//delete_option( 'decibel_v2_options_updated' );

	if ( get_option( 'decibel_v2_sync_options' ) ) {
		return;
	}

	// Accent Color
	set_theme_mod( 'accent_color', wolf_get_theme_option( 'accent_color' ) );

	// Mailchimp API key
	if ( wolf_get_theme_option( 'mailchimp_api_key' ) && function_exists( 'wvc_update_option' ) ) {
		wvc_update_option( 'mailchimp', 'mailchimp_api_key', wolf_get_theme_option( 'mailchimp_api_key' ) );
	}

	// Google fonts
	if ( wolf_get_theme_option( 'google_fonts' ) && function_exists( 'wvc_update_option' ) ) {
		
		if ( function_exists( 'decibel_update_option' ) ) {

			decibel_update_option( 'font', 'google_fonts', wolf_get_theme_option( 'google_fonts' ) );

		} elseif ( function_exists( 'decibel_update_option' ) ) {
			decibel_update_option( 'font', 'google_fonts', wolf_get_theme_option( 'google_fonts' ) );
		}
		
		wvc_update_option( 'fonts', 'google_fonts', wolf_get_theme_option( 'google_fonts' ) );
	}

	if ( get_option( 'decibel_v2_options_updated' ) ) {
		return;
	}

	// Logos
	wdv3_update_image_mod( 'logo_light' );
	wdv3_update_image_mod( 'logo_dark' );
	
	// Favicon
	wdv3_update_image_mod( 'favicon_114', 'site_icon' );
	wdv3_update_image_mod( 'body_bg_img', 'background_image' );

	// Conditional mods
	if ( 'repeat' === wolf_get_theme_option( 'body_bg_repeat' ) ) {
		set_theme_mod( 'background_repeat', 'true' );
	}

	if ( 'scroll' === wolf_get_theme_option( 'body_bg_attachment' ) ) {
		set_theme_mod( 'background_attachment', 'true' );
	}

	if ( wolf_get_theme_option( 'sticky_menu' ) ) {
		set_theme_mod( 'menu_sticky_type', 'hard' );
	}

	if ( wolf_get_theme_option( 'one_page_menu' ) ) {
		$one_page_id = wolf_get_theme_option( 'one_page_menu' );
		update_post_meta( $one_page_id, '_post_one_page_menu', 'replace_main_nav' );
	}

	if ( wolf_get_theme_option( 'additional_toggle_menu_type' ) ) {
		set_theme_mod( 'side_panel_position', 'right' );
	}

	if ( wolf_get_theme_option( 'page_transition' ) ) {
		set_theme_mod( 'loading_animation_type', 'spinner-loader8' );
	}

	if ( wolf_get_theme_option( 'blog_type' ) ) {
		$blog_type = wolf_get_theme_option( 'blog_type' );

		// large, sided, sidebar, masonry, grid

		if ( 'large' === $blog_type || 'sidebar' === $blog_type ) {
			set_theme_mod( 'post_layout', 'sidebar-right' );
			set_theme_mod( 'post_display', 'standard' );
		}

		if ( 'sided' === $blog_type ) {
			set_theme_mod( 'post_layout', 'fullwidth' );
			set_theme_mod( 'post_display', 'lateral' );
		}

		if ( 'masonry' === $blog_type ) {
			set_theme_mod( 'post_layout', 'fullwidth' );
			set_theme_mod( 'post_display', 'masonry' );
		}

		if ( 'grid' === $blog_type ) {
			set_theme_mod( 'post_layout', 'fullwidth' );
			set_theme_mod( 'post_display', 'grid_modern' );
			set_theme_mod( 'post_grid_padding', 'no' );
		}
	}

	set_theme_mod( 'after_header_block', '' );
	set_theme_mod( 'before_footer_block', '' );
	set_theme_mod( 'wrapper_width', '1400' );
	set_theme_mod( 'release_hover_effect', 'old' );
	set_theme_mod( 'gallery_hover_effect', 'old' );
	set_theme_mod( 'footer_widgets_layout', '4-cols' );
	set_theme_mod( 'menu_layout', 'top-right' );
	set_theme_mod( 'menu_hover_style', 'opacity' );
	set_theme_mod( 'menu_cta_content_type', 'custom' );

	// Options to move as mods as is
	$options_to_mods = array(
		
		'body_bg_color' => 'body_background_color',
		'body_bg_position' => 'background_position',
		'body_bg_size' => 'background_size',
		'body_bg_attachment' => 'background_position',
		'body_bg_position' => 'background_position',

		//'menu_position' => 'menu_layout',
		'menu_social_services' => 'menu_socials',
		'menu_width' => 'menu_width',
		//'menu_hover_effect' => 'menu_hover_style',
		'menu_style' => 'menu_style',

		'sub_menu_bg_color' => 'submenu_background_color',

		'breakpoint' => 'menu_breakpoint',

		'body_font_name' => 'body_font_name',
		
		'heading_font_name' => 'heading_font_name',
		'heading_font_weight' => 'heading_font_weight',
		'heading_font_style' => 'heading_font_style',
		'heading_font_transform' => 'heading_font_transform',
		'heading_font_letter_spacing' => 'heading_font_letter_spacing',

		'menu_font_name' => 'menu_font_name',
		'menu_font_weight' => 'menu_font_weight',
		'menu_font_style' => 'menu_font_style',
		'menu_font_transform' => 'menu_font_transform',
		'menu_font_letter_spacing' => 'menu_font_letter_spacing',

		'date_format' => 'date_format',
		'excerpt_type' => 'post_excerpt_type',
		//'blog_type' => 'post_display',
	);

	if ( function_exists( 'wvc_get_socials' ) ) {
		$socials = wvc_get_socials();
		foreach ( $socials as $s ) {
			
			set_theme_mod( $s, wolf_get_theme_option( $s ) );
			
			if ( function_exists( 'wvc_update_option' ) ) {
				wvc_update_option( 'socials', $s, wolf_get_theme_option( $s ) );
			}
		}
	}

	foreach ( $options_to_mods as $key => $value) {

		if ( wolf_get_theme_option( $key ) ) {
			set_theme_mod( $value, wolf_get_theme_option( $key ) );
		}
	}

	update_option( 'decibel_v2_options_updated', true );
	update_option( 'decibel_v2_sync_options', true );
}

/**
 * Set image theme mod from old theme option value
 */
function wdv3_update_image_mod( $old_id, $new_id = null ) {
		
	if ( ! $new_id ) {
		$new_id = $old_id;
	}

	set_theme_mod( $new_id, wdv3u_get_url_from_attachment_id( wolf_get_theme_option( $old_id ) ) );
}