<?php
/**
 * Wolf Decibel Version 3 Updater shortcode updater
 *
 * @author WolfThemes
 * @category Core
 * @package WolfDecibelVersion3Updater/Core
 * @version 1.0.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

include( 'shortcodes.php' );

/**
 * Update shortcodes
 */
function wdv3u_update_shortcodes_by_post_id( $post_id ) {

	$shortcodes_to_replace = wdv3u_get_shortcode_array();
	$post = get_post( $post_id );
	$content = $post->post_content;
	$_attrs_regex = wdv3u_get_shortcode_atts_regex();

	/**
	 * Update row shortcode
	 */
	$content = preg_replace_callback( '/\[vc_row ' . $_attrs_regex . '\]/', function( $matches ) use( $post_id, $shortcodes_to_replace ) {

		$new_output = '';
		$new_shortcode = '';

		foreach ( $matches as $shortcode ) {

			$new_shortcode = $shortcode;
			$atts = shortcode_parse_atts( str_replace( array( '[', ']' ), '', $shortcode ) );
			$base = $atts[0];
			unset( $atts[0] );

			//var_dump( $atts );

			$atts = apply_filters( 'wdv3u_row_atts', $atts );

			//var_dump( $atts );
			//var_dump( '---------------------------------------------------' );

			$new_shortcode = '[vc_row ';

			foreach ( $atts as $key => $value ) {

				if ( isset( $shortcodes_to_replace[ $base ]['atts'][ $key ] ) ) {
					$new_attr = $shortcodes_to_replace[ $base ]['atts'][ $value ];
					$atts[ $new_attr ] = $shortcodes_to_replace[ $base ]['atts'][ $value ];
					unset( $atts[ $key ] );
				}
			}

			foreach ( $atts as $key => $value ) {
				$new_shortcode .= $key .'="' . $value . '" ';
			}

			$new_shortcode .= ']';

			$new_output = str_replace( $shortcode, $new_shortcode, $shortcode );
		}

		return $new_output;

	}, $content );

	/**
	 * Update shortcodes content (testimonial, pricing tables, service tables)
	 *
	 * Get shortcode content and convert it to an attrubute
	 */
	$regex = get_shortcode_regex( array( 'wolf_testimonial' ) );
	$content = preg_replace_callback( '/' . $regex . '/', function( $matches ) use( $post_id, $shortcodes_to_replace ) {

		$new_output = '';
		$new_shortcode = '';

		if ( $matches && is_array( $matches ) && isset( $matches[0] ) && isset( $matches[2] ) && isset( $matches[5] ) ) {
			$shortcode = $matches[0];
			$base = $matches[2];
			$content = $matches[5];
			$new_content = wp_strip_all_tags( $content );

			$cleaned_shortcode = str_replace( array( "[/$base]", "[$base", ']', $content, ), '', $shortcode );
			$atts = shortcode_parse_atts( $cleaned_shortcode );

			if ( isset( $shortcodes_to_replace[ $base ] ) && isset( $shortcodes_to_replace[ $base ]['content_attr_name'] ) ) {

				$new_shortcode = "[$base ";

				$new_shortcode .= $shortcodes_to_replace[ $base ]['content_attr_name'] . '="' . $new_content . '" ';

				foreach ( $atts as $key => $value ) {

					$new_shortcode .= $key .'="' . $value . '" ';
				}

				$new_shortcode .= ']';

				//debug( $new_shortcode );
				
				$new_output = str_replace( $shortcode, $new_shortcode, $shortcode );
			}
		}

		return $new_output;

	}, $content );

	/**
	 * Update shortcode with attributes
	 */
	$content = preg_replace_callback( '/\[[a-zA-Z_0-9]+ ' . $_attrs_regex . '\]/', function( $matches ) use( $post_id, $shortcodes_to_replace ) {

		$new_output = '';
		$new_shortcode = '';

		foreach ( $matches as $shortcode ) {

			$new_shortcode = $shortcode;
			$atts = shortcode_parse_atts( str_replace( array( '[', ']' ), '', $shortcode ) );
			$base = $atts[0];

			$new_base = $base;
			unset( $atts[0] );

			/**
			 * Filter attributes
			 */
			$atts = apply_filters( 'wdv3u_shortcode_atts', $atts, $base );

			/**
			 * New base
			 */
			if ( isset( $shortcodes_to_replace[ $base ] ) && isset( $shortcodes_to_replace[ $base ]['base'] ) ) {
				$new_base = str_replace( $base, $shortcodes_to_replace[ $base ]['base'], $base );
			}

			$new_shortcode = '[' . $new_base . ' ';
			
			/**
			 * Replace atts
			 */
			foreach ( $atts as $key => $value ) {

				 if ( isset( $shortcodes_to_replace[ $base ]['atts'][ $key ] ) ) {
					$new_attr = $shortcodes_to_replace[ $base ]['atts'][ $key ];
					$atts[ $new_attr ] = $value;
					unset( $atts[ $key ] );
				}
			}

			/**
			 * Replace values
			 */
			foreach ( $atts as $key => $value ) {

				if ( isset( $shortcodes_to_replace[ $base ]['values'][ $value ] ) ) {
					//var_dump(  $key . ' => ' .  $value . ' => ' . $shortcodes_to_replace[ $base ]['values'][ $value ] );
					$atts[ $key ] = $shortcodes_to_replace[ $base ]['values'][ $value ];
				}
			}

			foreach ( $atts as $key => $value ) {

				$new_shortcode .= $key .'="' . $value . '" ';
			}

			$new_shortcode .= ']';

			//var_dump( $atts );
			//die();
		
			$new_output = str_replace( $shortcode, $new_shortcode, $shortcode );

			//var_dump( $new_shortcode );
		}

		return $new_output;

	}, $content );


	/**
	 * Update shortcodes without attributes
	 */
	$content = preg_replace_callback( '/\[[a-zA-Z_0-9\/]+\]/', function( $matches ) use( $post_id, $shortcodes_to_replace ) {

		$new_output = '';
		$new_shortcode = '';

		foreach ( $matches as $shortcode ) {

			$new_shortcode = $shortcode;
			$atts = shortcode_parse_atts( str_replace( array( '[', ']' ), '', $shortcode ) );
			$base = str_replace( '/', '', $atts[0] );

			if ( isset( $shortcodes_to_replace[ $base ] ) && isset( $shortcodes_to_replace[ $base ]['base'] ) ) {
				$new_shortcode = str_replace( $base, $shortcodes_to_replace[ $base ]['base'], $shortcode );
			}

			$new_output = str_replace( $shortcode, $new_shortcode, $shortcode );
		}

		return $new_output;

	}, $content );

	//var_dump( $post_id );
	//debug( $content );
	//die();
	
	return $content;

}

function wdv3u_update_content( $post_id ) {

	$content = wdv3u_update_shortcodes_by_post_id( $post_id );

	/**
	 * Update
	 */
	$new_post_args = array(
		'ID' => $post_id,
		'post_content' => $content,
	);

	d3_log( $post_id . ' => ' . $content );

	$post_id = wp_update_post( $new_post_args, true );
	if ( is_wp_error( $post_id ) ) {
		$errors = $post_id->get_error_messages();
		foreach ($errors as $error) {
			d3_log( $error );
		}
	}
}