<?php

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

if ( ! function_exists( 'wolf_shortcode_testimonials' ) ) {
	/**
	 * Testimonials shortcode
	 *
	 * @param array $atts
	 * @param array $content
	 * @return string
	 */
	function wolf_shortcode_testimonials( $atts, $content = null ) {

		if ( class_exists( 'Vc_Manager' ) && function_exists( 'vc_map_get_attributes' ) ) {
			$atts = vc_map_get_attributes( 'wolf_testimonials', $atts );
		}

		extract( shortcode_atts( array(
			'text_alignment' => 'center',
			'title' => '',
			'autoplay' => 'yes',
			'transition' => 'slide',
			'slideshow_speed' => 4000,
			'pause_on_hover' => 'yes',
			'nav_bullets' => 'yes',
			'nav_arrows' => 'yes',
			'css_animation' => '',
			'css_animation_delay' => '',
			'el_class' => '',
			'css' => '',
			'inline_style' => '',
		), $atts ) );

		$output = '';

		$class = $el_class;
		$inline_style = wvc_sanitize_css_field( $inline_style );
		$inline_style .= wvc_shortcode_custom_style( $css );

		/*Animate */
		if ( ! wvc_is_new_animation( $css_animation ) ) {
			$class .= wvc_get_css_animation( $css_animation );
			$inline_style .= wvc_get_css_animation_delay( $css_animation_delay );
		}

		wp_enqueue_script( 'flickity' );
		wp_enqueue_script( 'wvc-carousels' );

		$autoplay = esc_attr( $autoplay );
		$transition = esc_attr( $transition );
		$slideshow_speed = absint( $slideshow_speed );
		$pause_on_hover = esc_attr( $pause_on_hover );
		$nav_bullets = esc_attr( $nav_bullets );
		$nav_arrows = esc_attr( $nav_arrows );
		$title = esc_attr( $title );

		$class .= " wvc-testimonials-container wvc-testimonials-transition-$transition wvc-testimonials-text-align-$text_alignment wvc-element";

		if ( 'true' === $nav_bullets ) {
			$class .= ' wvc-testimonials-container-has-nav-bullets';
		}

		$slider_data = "data-pause-on-hover='$autoplay'
				data-autoplay='$autoplay'
				data-transition='$transition'
				data-slideshow-speed='$slideshow_speed'
				data-nav-arrows='$nav_arrows'
				data-nav-bullets='$nav_bullets'";

		$output = '<div class="' . wvc_sanitize_html_classes( $class ) . '" style="' . wvc_esc_style_attr( $inline_style ) . '"';

		$output .= wvc_element_aos_animation_data_attr( $atts );
		$output .= '>';

		$output .= "<div $slider_data class='wvc-testimonials-slider'>";

		$output .= wpb_js_remove_wpautop( $content );

		$output .= '</div></div>';

		return $output;
	}
	add_shortcode( 'wolf_testimonials', 'wolf_shortcode_testimonials' );
}

if ( ! function_exists( 'wolf_shortcode_testimonial' ) ) {
	/**
	 * Testimonial shortcode
	 *
	 * @param array $atts
	 * @param array $content
	 * @return string
	 */
	function wolf_shortcode_testimonial( $atts, $content = null ) {

		if ( class_exists( 'Vc_Manager' ) && function_exists( 'vc_map_get_attributes' ) ) {
			$atts = vc_map_get_attributes( 'wolf_testimonial', $atts );
		}

		extract( shortcode_atts( array(
			'name' => '',
			'avatar' => '',
			//'content' => '',
			'link' => '',
			'el_class' => '',
		), $atts ) );

		$output = $inline_style = '';

		$class = $el_class;

		// link
		$link = vc_build_link( $link );
		$link_url = ( isset( $link['url'] ) ) ? esc_url( $link['url'] ) : '#';
		$link_target = ( isset( $link['target'] ) ) ? esc_attr( trim( $link['target'] ) ) : '_self';
		$link_title = ( isset( $link['title'] ) ) ? esc_attr( $link['title'] ) : '';
		$nofollow = ( isset( $link['rel'] ) && 'nofollow' === $link['rel'] ) ? 'rel="nofollow"' : '';

		$cite = '<cite class="wvc-testimonial-cite">';

		if ( $avatar ) {

			$avatar = wvc_get_url_from_attachment_id( absint( $avatar ), apply_filters( 'wvc_testimonial_slide_avatar_size', 'thumbnail' ) );
		}

		if ( $name && $link_url ) {

			$link_url = esc_url( $link_url );
			$cite .= "<a $nofollow href='$link_url' target='_blank'>$name</a>";

		} elseif ( $name ) {
			$cite .= sanitize_text_field( $name );
		}

		$cite .= '</cite>';

		$output .= "<div class='wvc-testimonal-slide'><div class='wvc-testimonal-container'>";

		if ( $avatar ) {
			$output .= '<span class="wvc-testimonial-avatar"><img src="' . esc_url( $avatar ) . '" alt="testimonial-avatar"></span>';
		}

		$output .= "<blockquote class='wvc-testimonial-content'><p>";
		$output .= sanitize_text_field( $content );
		$output .= $cite;
		$output .= '<p></blockquote>';
		$output .= '</div>
		</div>';

		return $output;
	}
	add_shortcode( 'wolf_testimonial', 'wolf_shortcode_testimonial' );
}