<?php
/**
 * Wolf Decibel Version 3 Updater old Visual Composer functions
 *
 * @author WolfThemes
 * @category Core
 * @package WolfDecibelVersion3Updater/Core
 * @version 1.0.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

if ( ! class_exists( 'Wolf_Decibel_Version3_Updater_Vc' ) ) {
	class Wolf_Decibel_Version3_Updater_Vc {

		/**
		 * Wolf Decibel Version 3 Updater Constructor.
		 */
		public function __construct() {
			$this->includes();
			$this->init_hooks();
		}

		/**
		 * Hook into actions and filters
		 */
		private function init_hooks() {
			
			// Includes element after init hook to allow filtering by theme
			add_action( 'init', array( $this, 'include_elements' ) );

			add_action( 'wp_enqueue_scripts', array( $this, 'enqueue_scripts' ) );
		}

		/**
		 * Include required core files used in admin and on the frontend.
		 */
		public function includes() {
			include_once( 'inc/core-functions.php' );
			include_once( 'inc/icons.php' );
			include_once( 'inc/vc-extend.php' );

			if ( ( ! is_admin() || defined( 'DOING_AJAX' ) ) && ! defined( 'DOING_CRON' ) ) {
				include_once( 'inc/frontend-functions.php' );
			}
		}

		/**
		 * Include element files
		 */
		public function include_elements() {
			// Includes all shortcode files

			// Get elements list
			$elements_slugs = wdv3u_get_vc_element_list();

			foreach ( $elements_slugs as $slug ) {

				include_once( 'inc/elements/vc-' . $slug . '.php' );

				if ( is_file( WOLF_BACKCOMPAT_DIR . '/vc/inc/shortcodes/shortcode-' . $slug . '.php' ) ) {
					include_once( 'inc/shortcodes/shortcode-' . $slug . '.php' );
				}
			}
		}

		/**
		 * Get the plugin path.
		 * @return string
		 */
		public function plugin_path() {
			return untrailingslashit( plugin_dir_path( __FILE__ ) );
		}

		/**
		 * Get the plugin path.
		 * @return string
		 */
		public function plugin_uri() {
			return untrailingslashit( plugin_dir_path( __FILE__ ) );
		}

		/**
		 * Enqueue scripts & styles
		 */
		function enqueue_scripts() {

			$version = ( defined( 'SCRIPT_DEBUG' ) && SCRIPT_DEBUG ) ? time() : WDV3U_VERSION;

			wp_enqueue_style( 'wdv3u-styles', WOLF_BACKCOMPAT_URI . '/vc/css/old-vc.css', array(), $version );

			wp_enqueue_style( 'vc_linecons' );

			wp_enqueue_script( 'wow' );
			wp_enqueue_script( 'wdv3u-scripts', WOLF_BACKCOMPAT_URI . '/vc/js/old-vc.js', array( 'jquery' ), $version, true );
		}

	} // end class
	new Wolf_Decibel_Version3_Updater_Vc;
} // end if class exists